@@ -136,6 +136,12 @@ Examples:
             help="Create line-specific review comments on PR (requires --github-comment)",
         )
 
+        parser.add_argument(
+            "--github-summary",
+            action="store_true",
+            help="Write validation summary to GitHub Actions job summary (works for all workflow runs)",
+        )
+
         parser.add_argument(
             "--run-all-checks",
             action="store_true",
@@ -265,6 +271,10 @@ Examples:
                     if not success:
                         logging.error("Failed to post Access Analyzer results to GitHub PR")
 
+            # Write to GitHub Actions job summary if configured
+            if getattr(args, "github_summary", False):
+                self._write_github_actions_summary(report)
+
             # Determine exit code based on validation results
             if args.fail_on_warnings:
                 exit_code = 0 if report.total_findings == 0 else 1
@@ -377,10 +387,28 @@ Examples:
 
         # Post to GitHub if configured
         if args.github_comment:
+            from iam_validator.core.config.config_loader import ConfigLoader
             from iam_validator.core.pr_commenter import PRCommenter
 
+            # Load config to get fail_on_severity, severity_labels, and ignore settings
+            config_path = getattr(args, "config", None)
+            config = ConfigLoader.load_config(config_path)
+            fail_on_severities = config.get_setting("fail_on_severity", ["error", "critical"])
+            severity_labels = config.get_setting("severity_labels", {})
+
+            # Get ignore settings from config
+            ignore_settings = config.get_setting("ignore_settings", {})
+            enable_ignore = ignore_settings.get("enabled", True)
+            allowed_users = ignore_settings.get("allowed_users", [])
+
             async with GitHubIntegration() as github:
-                commenter = PRCommenter(github)
+                commenter = PRCommenter(
+                    github,
+                    fail_on_severities=fail_on_severities,
+                    severity_labels=severity_labels,
+                    enable_codeowners_ignore=enable_ignore,
+                    allowed_ignore_users=allowed_users,
+                )
                 success = await commenter.post_findings_to_pr(
                     validation_report,
                     create_review=getattr(args, "github_review", False),
@@ -405,7 +433,8 @@ Examples:
         if not github.is_configured():
             logging.error(
                 "GitHub integration not configured. "
-                "Set GITHUB_TOKEN, GITHUB_REPOSITORY, and GITHUB_PR_NUMBER"
+                "Required: GITHUB_TOKEN, GITHUB_REPOSITORY, and GITHUB_PR_NUMBER environment variables. "
+                "Ensure your workflow is triggered by a pull_request event."
             )
             return False
 
@@ -432,3 +461,89 @@ Examples:
             logging.error("Failed to post Access Analyzer results to PR")
 
         return success
+
+    def _write_github_actions_summary(self, report: AccessAnalyzerReport) -> None:
+        """Write a high-level summary to GitHub Actions job summary.
+
+        This appears in the Actions tab and provides a quick overview of Access Analyzer results.
+        Uses GITHUB_STEP_SUMMARY environment variable.
+
+        Args:
+            report: Access Analyzer report to summarize
+        """
+        import os
+
+        summary_file = os.getenv("GITHUB_STEP_SUMMARY")
+        if not summary_file:
+            logging.warning(
+                "--github-summary specified but GITHUB_STEP_SUMMARY env var not found. "
+                "This feature only works in GitHub Actions."
+            )
+            return
+
+        try:
+            # Generate high-level summary
+            summary_parts = []
+
+            # Header with status
+            if report.total_findings == 0:
+                summary_parts.append("# ✅ IAM Policy Validation (Access Analyzer) - Passed")
+            elif report.total_errors > 0:
+                summary_parts.append("# ❌ IAM Policy Validation (Access Analyzer) - Failed")
+            else:
+                summary_parts.append("# ⚠️ IAM Policy Validation (Access Analyzer) - Issues Found")
+
+            summary_parts.append("")
+
+            # Summary table
+            summary_parts.append("## Summary")
+            summary_parts.append("")
+            summary_parts.append("| Metric | Count |")
+            summary_parts.append("|--------|-------|")
+            summary_parts.append(f"| Total Policies Analyzed | {report.total_policies} |")
+            summary_parts.append(f"| Policies with Findings | {report.policies_with_findings} |")
+            summary_parts.append(f"| Total Findings | {report.total_findings} |")
+            summary_parts.append(f"| Errors | {report.total_errors} |")
+            summary_parts.append(f"| Warnings | {report.total_warnings} |")
+            summary_parts.append(f"| Suggestions | {report.total_suggestions} |")
+
+            # Finding breakdown by type if there are findings
+            if report.total_findings > 0:
+                summary_parts.append("")
+                summary_parts.append("## 📊 Findings by Type")
+                summary_parts.append("")
+
+                # Count findings by type
+                finding_types: dict[str, int] = {}
+                for result in report.results:
+                    for finding in result.findings:
+                        finding_type = finding.finding_type
+                        finding_types[finding_type] = finding_types.get(finding_type, 0) + 1
+
+                # Sort by count (highest first)
+                sorted_types = sorted(finding_types.items(), key=lambda x: x[1], reverse=True)
+
+                summary_parts.append("| Finding Type | Count |")
+                summary_parts.append("|--------------|-------|")
+                for finding_type, count in sorted_types:
+                    summary_parts.append(f"| {finding_type} | {count} |")
+
+            # Add footer with links
+            summary_parts.append("")
+            summary_parts.append("---")
+            summary_parts.append("")
+            summary_parts.append(
+                "📝 For detailed findings, check the PR comments or review the workflow logs."
+            )
+            summary_parts.append("")
+            summary_parts.append("*Powered by AWS IAM Access Analyzer*")
+
+            # Write to summary file (append mode)
+            with open(summary_file, "a", encoding="utf-8") as f:
+                f.write("\n".join(summary_parts))
+                f.write("\n")
+
+            logging.info("Wrote Access Analyzer summary to GitHub Actions job summary")
+
+        except Exception as e:
+            logging.warning(f"Failed to write GitHub Actions summary: {e}")
