@@ -1,13 +1,12 @@
 """Core validation modules."""
 
-from iam_validator.core.aws_fetcher import AWSServiceFetcher
-from iam_validator.core.policy_checks import PolicyValidator, validate_policies
+from iam_validator.core.aws_service import AWSServiceFetcher
+from iam_validator.core.policy_checks import validate_policies
 from iam_validator.core.policy_loader import PolicyLoader
 from iam_validator.core.report import ReportGenerator
 
 __all__ = [
     "AWSServiceFetcher",
-    "PolicyValidator",
     "validate_policies",
     "PolicyLoader",
     "ReportGenerator",
