@@ -8,6 +8,7 @@ from rich.panel import Panel
 from rich.table import Table
 from rich.text import Text
 
+from iam_validator.__version__ import __version__
 from iam_validator.core.access_analyzer import (
     AccessAnalyzerFinding,
     AccessAnalyzerReport,
@@ -70,7 +71,7 @@ class AccessAnalyzerReportFormatter:
 
         panel = Panel(
             summary_text,
-            title="[bold]Access Analyzer Validation Summary[/bold]",
+            title=f"[bold]Access Analyzer Validation Summary (iam-validator v{__version__})[/bold]",
             border_style="blue",
         )
         self.console.print(panel)
@@ -258,7 +259,7 @@ class AccessAnalyzerReportFormatter:
             file_path: Path to save JSON report
         """
         json_content = self.generate_json_report(report)
-        with open(file_path, "w") as f:
+        with open(file_path, "w", encoding="utf-8") as f:
             f.write(json_content)
 
     def generate_markdown_report(
@@ -337,11 +338,8 @@ class AccessAnalyzerReportFormatter:
             "---",
             "",
             "<div align='center'>",
-            "",
-            "**🤖 Generated by IAM Policy Validator**",
-            "",
-            "_Powered by AWS IAM Access Analyzer_",
-            "",
+            "🤖 <em>Generated by <strong>IAM Policy Validator</strong></em><br>",
+            "<sub>Powered by AWS IAM Access Analyzer</sub>",
             "</div>",
         ]
         footer_content = "\n".join(footer_lines)
@@ -638,5 +636,5 @@ class AccessAnalyzerReportFormatter:
             file_path: Path to save Markdown report
         """
         markdown_content = self.generate_markdown_report(report)
-        with open(file_path, "w") as f:
+        with open(file_path, "w", encoding="utf-8") as f:
             f.write(markdown_content)
