@@ -10,11 +10,12 @@ This module provides a pluggable check system that allows:
 """
 
 import asyncio
-from abc import ABC, abstractmethod
+from abc import ABC
 from dataclasses import dataclass, field
 from typing import TYPE_CHECKING, Any
 
-from iam_validator.core.aws_fetcher import AWSServiceFetcher
+from iam_validator.core.aws_service import AWSServiceFetcher
+from iam_validator.core.ignore_patterns import IgnorePatternMatcher
 from iam_validator.core.models import Statement, ValidationIssue
 
 if TYPE_CHECKING:
@@ -30,6 +31,70 @@ class CheckConfig:
     severity: str | None = None  # Override default severity
     config: dict[str, Any] = field(default_factory=dict)  # Check-specific config
     description: str = ""
+    root_config: dict[str, Any] = field(default_factory=dict)  # Full config for cross-check access
+    ignore_patterns: list[dict[str, Any]] = field(default_factory=list)  # NEW: Ignore patterns
+    """
+    List of patterns to ignore findings.
+
+    Each pattern is a dict with optional fields:
+    - filepath: Regex to match file path
+    - action: Regex to match action name
+    - resource: Regex to match resource
+    - sid: Exact SID to match (or regex if ends with .*)
+    - condition_key: Regex to match condition key
+
+    Multiple fields in one pattern = AND logic
+    Multiple patterns = OR logic (any pattern matches → ignore)
+
+    Example:
+        ignore_patterns:
+          - filepath: "test/.*|examples/.*"
+          - filepath: "policies/readonly-.*"
+            action: ".*:(Get|List|Describe).*"
+          - sid: "AllowReadOnlyAccess"
+    """
+
+    def should_ignore(self, issue: ValidationIssue, filepath: str = "") -> bool:
+        """
+        Check if issue should be ignored based on ignore patterns.
+
+        Uses centralized IgnorePatternMatcher for high-performance filtering
+        with cached compiled regex patterns.
+
+        Args:
+            issue: The validation issue to check
+            filepath: Path to the policy file
+
+        Returns:
+            True if the issue should be ignored
+
+        Performance:
+            - Cached regex compilation (LRU cache)
+            - Early exit optimization
+        """
+        return IgnorePatternMatcher.should_ignore_issue(issue, filepath, self.ignore_patterns)
+
+    def filter_actions(self, actions: frozenset[str]) -> frozenset[str]:
+        """
+        Filter actions based on action ignore patterns.
+
+        Uses centralized IgnorePatternMatcher for high-performance filtering
+        with cached compiled regex patterns.
+
+        This is useful for checks that need to filter a set of actions before
+        creating ValidationIssues (e.g., sensitive_action check).
+
+        Args:
+            actions: Set of actions to filter
+
+        Returns:
+            Filtered set of actions (actions matching ignore patterns removed)
+
+        Performance:
+            - Cached regex compilation (LRU cache)
+            - Early exit per action on first match
+        """
+        return IgnorePatternMatcher.filter_actions(actions, self.ignore_patterns)
 
 
 class PolicyCheck(ABC):
@@ -38,38 +103,101 @@ class PolicyCheck(ABC):
 
     To create a custom check:
     1. Inherit from this class
-    2. Implement check_id, description, and execute()
-    3. Register with CheckRegistry
+    2. Implement check_id and description (required)
+    3. Implement either execute() OR execute_policy() (or both)
+    4. Register with CheckRegistry
 
-    Example:
-        class MyCustomCheck(PolicyCheck):
-            check_id = "my_custom_check"
-            description = "Validates custom compliance rules"
+    Two ways to define check_id and description:
+
+    Option 1 - Class attributes (simpler, recommended for static values):
+        from typing import ClassVar
+
+        class MyCheck(PolicyCheck):
+            check_id: ClassVar[str] = "my_check"
+            description: ClassVar[str] = "My check description"
 
             async def execute(self, statement, statement_idx, fetcher, config):
+                return []
+
+        Note: ClassVar annotation is required for Pylance type checker compatibility.
+
+    Option 2 - Property decorators (more flexible, supports dynamic values):
+        class MyCheck(PolicyCheck):
+            @property
+            def check_id(self) -> str:
+                return "my_check"
+
+            @property
+            def description(self) -> str:
+                return "My check description"
+
+            async def execute(self, statement, statement_idx, fetcher, config):
+                return []
+
+    Statement-level check example:
+        from typing import ClassVar
+
+        class MyStatementCheck(PolicyCheck):
+            check_id: ClassVar[str] = "my_statement_check"
+            description: ClassVar[str] = "Validates individual statements"
+
+            async def execute(self, statement, statement_idx, fetcher, config):
+                issues = []
+                # Your validation logic here
+                return issues
+
+    Policy-level check example:
+        from typing import ClassVar
+
+        class MyPolicyCheck(PolicyCheck):
+            check_id: ClassVar[str] = "my_policy_check"
+            description: ClassVar[str] = "Validates entire policy"
+
+            async def execute_policy(self, policy, policy_file, fetcher, config, **kwargs):
                 issues = []
                 # Your validation logic here
                 return issues
     """
 
     @property
-    @abstractmethod
     def check_id(self) -> str:
         """Unique identifier for this check (e.g., 'action_validation')."""
-        pass
+        raise NotImplementedError("Subclasses must define check_id")
 
     @property
-    @abstractmethod
     def description(self) -> str:
         """Human-readable description of what this check does."""
-        pass
+        raise NotImplementedError("Subclasses must define description")
 
     @property
     def default_severity(self) -> str:
         """Default severity level for issues found by this check."""
         return "warning"
 
-    @abstractmethod
+    def __init_subclass__(cls, **kwargs):
+        """
+        Validate that subclasses override at least one execution method.
+
+        This ensures checks implement either execute() OR execute_policy() (or both).
+        If neither is overridden, the check would never produce any results.
+        """
+        super().__init_subclass__(**kwargs)
+
+        # Skip validation for abstract classes
+        if ABC in cls.__bases__:
+            return
+
+        # Check if at least one method is overridden
+        has_execute = cls.execute is not PolicyCheck.execute
+        has_execute_policy = cls.execute_policy is not PolicyCheck.execute_policy
+
+        if not has_execute and not has_execute_policy:
+            raise TypeError(
+                f"Check '{cls.__name__}' must override at least one of: "
+                "execute() for statement-level checks, or "
+                "execute_policy() for policy-level checks"
+            )
+
     async def execute(
         self,
         statement: Statement,
@@ -80,6 +208,10 @@ class PolicyCheck(ABC):
         """
         Execute the check on a policy statement.
 
+        This method is called for statement-level checks. If your check only needs
+        to examine the entire policy (not individual statements), you can leave this
+        as the default implementation and override execute_policy() instead.
+
         Args:
             statement: The IAM policy statement to check
             statement_idx: Index of the statement in the policy
@@ -89,7 +221,8 @@ class PolicyCheck(ABC):
         Returns:
             List of ValidationIssue objects found by this check
         """
-        pass
+        del statement, statement_idx, fetcher, config  # Unused in default implementation
+        return []
 
     async def execute_policy(
         self,
@@ -97,6 +230,7 @@ class PolicyCheck(ABC):
         policy_file: str,
         fetcher: AWSServiceFetcher,
         config: CheckConfig,
+        **kwargs,
     ) -> list[ValidationIssue]:
         """
         Execute the check on the entire policy (optional method).
@@ -112,6 +246,7 @@ class PolicyCheck(ABC):
             policy_file: Path to the policy file (for context/reporting)
             fetcher: AWS service fetcher for validation against AWS APIs
             config: Configuration for this check instance
+            **kwargs: Additional context (policy_type, etc.)
 
         Returns:
             List of ValidationIssue objects found by this check
@@ -261,6 +396,7 @@ class CheckRegistry:
         statement: Statement,
         statement_idx: int,
         fetcher: AWSServiceFetcher,
+        filepath: str = "",
     ) -> list[ValidationIssue]:
         """
         Execute all enabled checks in parallel for maximum performance.
@@ -272,9 +408,10 @@ class CheckRegistry:
             statement: The IAM policy statement to validate
             statement_idx: Index of the statement in the policy
             fetcher: AWS service fetcher for API calls
+            filepath: Path to the policy file (for ignore_patterns filtering)
 
         Returns:
-            List of all ValidationIssue objects from all checks
+            List of all ValidationIssue objects from all checks (filtered by ignore_patterns)
         """
         enabled_checks = self.get_enabled_checks()
 
@@ -288,21 +425,31 @@ class CheckRegistry:
                 config = self.get_config(check.check_id)
                 if config:
                     issues = await check.execute(statement, statement_idx, fetcher, config)
-                    all_issues.extend(issues)
+                    # Inject check_id into each issue
+                    for issue in issues:
+                        if issue.check_id is None:
+                            issue.check_id = check.check_id
+                    # Filter issues based on ignore_patterns
+                    filtered_issues = [
+                        issue for issue in issues if not config.should_ignore(issue, filepath)
+                    ]
+                    all_issues.extend(filtered_issues)
             return all_issues
 
         # Execute all checks in parallel
         tasks = []
+        configs = []
         for check in enabled_checks:
             config = self.get_config(check.check_id)
             if config:
                 task = check.execute(statement, statement_idx, fetcher, config)
                 tasks.append(task)
+                configs.append(config)
 
         # Wait for all checks to complete
         results = await asyncio.gather(*tasks, return_exceptions=True)
 
-        # Collect all issues, handling any exceptions
+        # Collect all issues, handling any exceptions and applying ignore_patterns
         all_issues = []
         for idx, result in enumerate(results):
             if isinstance(result, Exception):
@@ -310,7 +457,17 @@ class CheckRegistry:
                 check = enabled_checks[idx]
                 print(f"Warning: Check '{check.check_id}' failed: {result}")
             elif isinstance(result, list):
-                all_issues.extend(result)
+                check = enabled_checks[idx]
+                config = configs[idx]
+                # Inject check_id into each issue
+                for issue in result:
+                    if issue.check_id is None:
+                        issue.check_id = check.check_id
+                # Filter issues based on ignore_patterns
+                filtered_issues = [
+                    issue for issue in result if not config.should_ignore(issue, filepath)
+                ]
+                all_issues.extend(filtered_issues)
 
         return all_issues
 
@@ -352,6 +509,8 @@ class CheckRegistry:
         policy: "IAMPolicy",
         policy_file: str,
         fetcher: AWSServiceFetcher,
+        policy_type: str = "IDENTITY_POLICY",
+        **kwargs,
     ) -> list[ValidationIssue]:
         """
         Execute all enabled policy-level checks.
@@ -363,6 +522,8 @@ class CheckRegistry:
             policy: The complete IAM policy to validate
             policy_file: Path to the policy file (for context/reporting)
             fetcher: AWS service fetcher for API calls
+            policy_type: Type of policy (IDENTITY_POLICY, RESOURCE_POLICY, SERVICE_CONTROL_POLICY)
+            **kwargs: Additional arguments to pass to checks (e.g., raw_policy_dict)
 
         Returns:
             List of all ValidationIssue objects from all policy-level checks
@@ -382,31 +543,62 @@ class CheckRegistry:
                 config = self.get_config(check.check_id)
                 if config:
                     try:
-                        issues = await check.execute_policy(policy, policy_file, fetcher, config)
-                        all_issues.extend(issues)
+                        issues = await check.execute_policy(
+                            policy,
+                            policy_file,
+                            fetcher,
+                            config,
+                            policy_type=policy_type,
+                            **kwargs,
+                        )
+                        # Inject check_id into each issue
+                        for issue in issues:
+                            if issue.check_id is None:
+                                issue.check_id = check.check_id
+                        # Filter issues based on ignore_patterns
+                        filtered_issues = [
+                            issue
+                            for issue in issues
+                            if not config.should_ignore(issue, policy_file)
+                        ]
+                        all_issues.extend(filtered_issues)
                     except Exception as e:
                         print(f"Warning: Check '{check.check_id}' failed: {e}")
             return all_issues
 
         # Execute all policy-level checks in parallel
         tasks = []
+        configs = []
         for check in policy_level_checks:
             config = self.get_config(check.check_id)
             if config:
-                task = check.execute_policy(policy, policy_file, fetcher, config)
+                task = check.execute_policy(
+                    policy, policy_file, fetcher, config, policy_type=policy_type, **kwargs
+                )
                 tasks.append(task)
+                configs.append(config)
 
         # Wait for all checks to complete
         results = await asyncio.gather(*tasks, return_exceptions=True)
 
-        # Collect all issues, handling any exceptions
+        # Collect all issues, handling any exceptions and applying ignore_patterns
         for idx, result in enumerate(results):
             if isinstance(result, Exception):
                 # Log error but continue with other checks
                 check = policy_level_checks[idx]
                 print(f"Warning: Check '{check.check_id}' failed: {result}")
             elif isinstance(result, list):
-                all_issues.extend(result)
+                check = policy_level_checks[idx]
+                config = configs[idx]
+                # Inject check_id into each issue
+                for issue in result:
+                    if issue.check_id is None:
+                        issue.check_id = check.check_id
+                # Filter issues based on ignore_patterns
+                filtered_issues = [
+                    issue for issue in result if not config.should_ignore(issue, policy_file)
+                ]
+                all_issues.extend(filtered_issues)
 
         return all_issues
 
@@ -431,26 +623,57 @@ def create_default_registry(
 
     if include_builtin_checks:
         # Import and register built-in checks
-        from iam_validator.checks import (
-            ActionConditionEnforcementCheck,
-            ActionValidationCheck,
-            ConditionKeyValidationCheck,
-            PolicySizeCheck,
-            ResourceValidationCheck,
-            SecurityBestPracticesCheck,
-            SidUniquenessCheck,
-        )
+        from iam_validator import checks
 
-        registry.register(ActionValidationCheck())
-        registry.register(ConditionKeyValidationCheck())
-        registry.register(ResourceValidationCheck())
-        registry.register(SecurityBestPracticesCheck())
-        registry.register(ActionConditionEnforcementCheck())
-        registry.register(SidUniquenessCheck())
-        registry.register(PolicySizeCheck())
+        # 0. FUNDAMENTAL STRUCTURE (Must run FIRST - validates basic policy structure)
+        registry.register(
+            checks.PolicyStructureCheck()
+        )  # Policy-level: Validates required fields, conflicts, valid values
 
-        # Note: SID uniqueness check is registered above but its actual execution
-        # happens at the policy level in _validate_policy_with_registry() since it
-        # needs to see all statements together to find duplicates
+        # 1. POLICY STRUCTURE (Checks that examine the entire policy, not individual statements)
+        registry.register(
+            checks.SidUniquenessCheck()
+        )  # Policy-level: Duplicate SID detection across statements
+        registry.register(checks.PolicySizeCheck())  # Policy-level: Size limit validation
+
+        # 2. IAM VALIDITY (AWS syntax validation - must pass before deeper checks)
+        registry.register(checks.ActionValidationCheck())  # Validate actions against AWS API
+        registry.register(checks.ResourceValidationCheck())  # Validate resource ARNs
+        registry.register(checks.ConditionKeyValidationCheck())  # Validate condition keys
+
+        # 3. TYPE VALIDATION (Condition operator type checking)
+        registry.register(checks.ConditionTypeMismatchCheck())  # Operator-value type compatibility
+        registry.register(checks.SetOperatorValidationCheck())  # ForAllValues/ForAnyValue usage
+
+        # 4. RESOURCE MATCHING (Action-resource relationship validation)
+        registry.register(
+            checks.ActionResourceMatchingCheck()
+        )  # ARN type matching and resource constraints
+
+        # 5. SECURITY - WILDCARDS (Security best practices for wildcards)
+        registry.register(checks.WildcardActionCheck())  # Wildcard action detection
+        registry.register(checks.WildcardResourceCheck())  # Wildcard resource detection
+        registry.register(checks.FullWildcardCheck())  # Full wildcard (*) detection
+        registry.register(checks.ServiceWildcardCheck())  # Service-level wildcard detection
+
+        # 6. SECURITY - ADVANCED (Sensitive actions and condition enforcement)
+        registry.register(
+            checks.SensitiveActionCheck()
+        )  # Policy-level: Privilege escalation detection (all_of across statements)
+        registry.register(
+            checks.ActionConditionEnforcementCheck()
+        )  # Statement + Policy-level: Condition enforcement (any_of/all_of/none_of)
+        registry.register(checks.MFAConditionCheck())  # MFA anti-pattern detection
+
+        # 7. PRINCIPAL VALIDATION (Resource policy specific)
+        registry.register(
+            checks.PrincipalValidationCheck()
+        )  # Principal validation (resource policies)
+        registry.register(
+            checks.TrustPolicyValidationCheck()
+        )  # Trust policy validation (role assumption policies)
+
+        # Note: policy_type_validation is a standalone function (not a class-based check)
+        # and is called separately in the validation flow
 
     return registry
