@@ -11,9 +11,12 @@ from rich.panel import Panel
 from rich.table import Table
 from rich.text import Text
 
+from iam_validator.__version__ import __version__
+from iam_validator.core import constants
 from iam_validator.core.formatters import (
     ConsoleFormatter,
     CSVFormatter,
+    EnhancedFormatter,
     HTMLFormatter,
     JSONFormatter,
     MarkdownFormatter,
@@ -43,6 +46,8 @@ class ReportGenerator:
         # Register all built-in formatters
         if not self.formatter_registry.get_formatter("console"):
             self.formatter_registry.register(ConsoleFormatter())
+        if not self.formatter_registry.get_formatter("enhanced"):
+            self.formatter_registry.register(EnhancedFormatter())
         if not self.formatter_registry.get_formatter("json"):
             self.formatter_registry.register(JSONFormatter())
         if not self.formatter_registry.get_formatter("markdown"):
@@ -67,11 +72,16 @@ class ReportGenerator:
         """
         return self.formatter_registry.format_report(report, format_id, **kwargs)
 
-    def generate_report(self, results: list[PolicyValidationResult]) -> ValidationReport:
+    def generate_report(
+        self,
+        results: list[PolicyValidationResult],
+        parsing_errors: list[tuple[str, str]] | None = None,
+    ) -> ValidationReport:
         """Generate a validation report from results.
 
         Args:
             results: List of policy validation results
+            parsing_errors: Optional list of (file_path, error_message) for files that failed to parse
 
         Returns:
             ValidationReport
@@ -80,12 +90,29 @@ class ReportGenerator:
         invalid_count = len(results) - valid_count
         total_issues = sum(len(r.issues) for r in results)
 
+        # Count policies with security issues (separate from validity issues)
+        policies_with_security_issues = sum(
+            1 for r in results if any(issue.is_security_severity() for issue in r.issues)
+        )
+
+        # Count validity vs security issues
+        validity_issues = sum(
+            sum(1 for issue in r.issues if issue.is_validity_severity()) for r in results
+        )
+        security_issues = sum(
+            sum(1 for issue in r.issues if issue.is_security_severity()) for r in results
+        )
+
         return ValidationReport(
             total_policies=len(results),
             valid_policies=valid_count,
             invalid_policies=invalid_count,
+            policies_with_security_issues=policies_with_security_issues,
             total_issues=total_issues,
+            validity_issues=validity_issues,
+            security_issues=security_issues,
             results=results,
+            parsing_errors=parsing_errors or [],
         )
 
     def print_console_report(self, report: ValidationReport) -> None:
@@ -98,10 +125,41 @@ class ReportGenerator:
         summary_text = Text()
         summary_text.append(f"Total Policies: {report.total_policies}\n")
         summary_text.append(f"Valid: {report.valid_policies} ", style="green")
-        summary_text.append(f"Invalid: {report.invalid_policies}\n", style="red")
-        summary_text.append(f"Total Issues: {report.total_issues}\n")
 
-        self.console.print(Panel(summary_text, title="Validation Summary", border_style="blue"))
+        # Show invalid policies (IAM validity issues)
+        if report.invalid_policies > 0:
+            summary_text.append(f"Invalid: {report.invalid_policies} ", style="red")
+
+        # Show policies with security findings (separate from validity)
+        if report.policies_with_security_issues > 0:
+            summary_text.append(
+                f"Security Findings: {report.policies_with_security_issues} ",
+                style="yellow",
+            )
+
+        summary_text.append("\n")
+
+        # Breakdown of issue types
+        summary_text.append(f"Total Issues: {report.total_issues}")
+        if report.validity_issues > 0 or report.security_issues > 0:
+            summary_text.append(" (")
+            if report.validity_issues > 0:
+                summary_text.append(f"{report.validity_issues} validity", style="red")
+            if report.validity_issues > 0 and report.security_issues > 0:
+                summary_text.append(", ")
+            if report.security_issues > 0:
+                summary_text.append(f"{report.security_issues} security", style="yellow")
+            summary_text.append(")")
+        summary_text.append("\n")
+
+        self.console.print(
+            Panel(
+                summary_text,
+                title=f"Validation Summary (iam-validator v{__version__})",
+                border_style="blue",
+                width=constants.CONSOLE_PANEL_WIDTH,
+            )
+        )
 
         # Detailed results
         for result in report.results:
@@ -127,11 +185,12 @@ class ReportGenerator:
             self.console.print("  [dim]No issues found[/dim]")
             return
 
-        # Create issues table
-        table = Table(show_header=True, header_style="bold", box=None, padding=(0, 1))
-        table.add_column("Severity", style="cyan", width=10)
-        table.add_column("Type", style="magenta", width=20)
-        table.add_column("Message", style="white")
+        # Create issues table with flexible column widths
+        # Use wider columns and more padding to better utilize terminal width
+        table = Table(show_header=True, header_style="bold", box=None, padding=(0, 2), expand=True)
+        table.add_column("Severity", style="cyan", no_wrap=True, min_width=12)
+        table.add_column("Type", style="magenta", no_wrap=False, min_width=32)
+        table.add_column("Message", style="white", no_wrap=False, ratio=3)
 
         for issue in result.issues:
             severity_style = {
@@ -146,13 +205,19 @@ class ReportGenerator:
                 "low": "[cyan]LOW[/cyan]",
             }.get(issue.severity, issue.severity.upper())
 
-            location = f"Statement {issue.statement_index}"
+            # Use 1-indexed statement numbers for user-facing output
+            statement_num = issue.statement_index + 1
+            location = f"Statement {statement_num}"
             if issue.statement_sid:
                 location += f" ({issue.statement_sid})"
+            if issue.line_number is not None:
+                location += f" @L{issue.line_number}"
 
             message = f"{location}: {issue.message}"
             if issue.suggestion:
                 message += f"\n  → {issue.suggestion}"
+            if issue.example:
+                message += f"\n[dim]Example:[/dim]\n[dim]{issue.example}[/dim]"
 
             table.add_row(severity_style, issue.issue_type, message)
 
@@ -170,13 +235,17 @@ class ReportGenerator:
         return report.model_dump_json(indent=2)
 
     def generate_github_comment_parts(
-        self, report: ValidationReport, max_length_per_part: int = 60000
+        self,
+        report: ValidationReport,
+        max_length_per_part: int = constants.GITHUB_COMMENT_SPLIT_LIMIT,
+        ignored_count: int = 0,
     ) -> list[str]:
         """Generate GitHub PR comment(s), splitting into multiple parts if needed.
 
         Args:
             report: Validation report
-            max_length_per_part: Maximum character length per comment part (default 60000)
+            max_length_per_part: Maximum character length per comment part (default from GITHUB_COMMENT_SPLIT_LIMIT)
+            ignored_count: Number of findings that were ignored (will be shown in summary)
 
         Returns:
             List of comment parts (each under max_length_per_part)
@@ -188,13 +257,13 @@ class ReportGenerator:
         if estimated_size <= max_length_per_part:
             # Try single comment
             single_comment = self.generate_github_comment(
-                report, max_length=max_length_per_part * 2
+                report, max_length=max_length_per_part * 2, ignored_count=ignored_count
             )
             if len(single_comment) <= max_length_per_part:
                 return [single_comment]
 
         # Need to split into multiple parts
-        return self._generate_split_comments(report, max_length_per_part)
+        return self._generate_split_comments(report, max_length_per_part, ignored_count)
 
     def _estimate_report_size(self, report: ValidationReport) -> int:
         """Estimate the size of the report in characters.
@@ -206,16 +275,19 @@ class ReportGenerator:
             Estimated character count
         """
         # Rough estimate: ~500 chars per issue + overhead
-        base_overhead = 2000  # Header + footer
-        chars_per_issue = 500
-        return base_overhead + (report.total_issues * chars_per_issue)
+        return constants.COMMENT_BASE_OVERHEAD_CHARS + (
+            report.total_issues * constants.COMMENT_CHARS_PER_ISSUE_ESTIMATE
+        )
 
-    def _generate_split_comments(self, report: ValidationReport, max_length: int) -> list[str]:
+    def _generate_split_comments(
+        self, report: ValidationReport, max_length: int, ignored_count: int = 0
+    ) -> list[str]:
         """Split a large report into multiple comment parts.
 
         Args:
             report: Validation report
             max_length: Maximum length per part
+            ignored_count: Number of ignored findings to show in summary
 
         Returns:
             List of comment parts
@@ -223,7 +295,7 @@ class ReportGenerator:
         parts: list[str] = []
 
         # Generate header (will be in first part only)
-        header_lines = self._generate_header(report)
+        header_lines = self._generate_header(report, ignored_count)
         header_content = "\n".join(header_lines)
 
         # Generate footer (will be in all parts)
@@ -235,13 +307,13 @@ class ReportGenerator:
         # - Part indicator: "**(Part N/M)**\n\n" (estimated ~20 chars)
         # - HTML comment identifier: "<!-- iam-policy-validator -->\n" (~35 chars)
         # - Safety buffer for formatting
-        continuation_overhead = 200
+        continuation_overhead = constants.COMMENT_CONTINUATION_OVERHEAD_CHARS
 
         # Sort results to prioritize errors - support both IAM validity and security severities
         sorted_results = sorted(
             [(idx, r) for idx, r in enumerate(report.results, 1) if r.issues],
             key=lambda x: (
-                -sum(1 for i in x[1].issues if i.severity in ("error", "critical", "high")),
+                -sum(1 for i in x[1].issues if i.severity in constants.HIGH_SEVERITY_LEVELS),
                 -len(x[1].issues),
             ),
         )
@@ -316,8 +388,13 @@ class ReportGenerator:
 
         return parts
 
-    def _generate_header(self, report: ValidationReport) -> list[str]:
-        """Generate the comment header with summary."""
+    def _generate_header(self, report: ValidationReport, ignored_count: int = 0) -> list[str]:
+        """Generate the comment header with summary.
+
+        Args:
+            report: Validation report
+            ignored_count: Number of findings that were ignored
+        """
         lines = []
 
         # Title with emoji and status badge
@@ -347,6 +424,8 @@ class ReportGenerator:
         lines.append(
             f"| **Total Issues Found** | {report.total_issues} | {'⚠️' if report.total_issues > 0 else '✨'} |"
         )
+        if ignored_count > 0:
+            lines.append(f"| **Ignored Findings** | {ignored_count} | 🔕 |")
         lines.append("")
 
         # Issue breakdown
@@ -356,7 +435,7 @@ class ReportGenerator:
                 1
                 for r in report.results
                 for i in r.issues
-                if i.severity in ("error", "critical", "high")
+                if i.severity in constants.HIGH_SEVERITY_LEVELS
             )
             warnings = sum(
                 1 for r in report.results for i in r.issues if i.severity in ("warning", "medium")
@@ -365,8 +444,7 @@ class ReportGenerator:
                 1 for r in report.results for i in r.issues if i.severity in ("info", "low")
             )
 
-            lines.append("<details>")
-            lines.append("<summary><b>🔍 Issue Breakdown</b></summary>")
+            lines.append("### 🔍 Issue Breakdown")
             lines.append("")
             lines.append("| Severity | Count |")
             lines.append("|----------|------:|")
@@ -377,8 +455,6 @@ class ReportGenerator:
             if infos > 0:
                 lines.append(f"| 🔵 **Info** | {infos} |")
             lines.append("")
-            lines.append("</details>")
-            lines.append("")
 
         return lines
 
@@ -389,11 +465,7 @@ class ReportGenerator:
                 "---",
                 "",
                 "<div align='center'>",
-                "",
-                "**🤖 Generated by IAM Policy Validator**",
-                "",
-                "_Powered by AWS IAM Access Analyzer and custom policy checks_",
-                "",
+                "🤖 <em>Generated by <strong>IAM Policy Validator</strong></em><br>",
                 "</div>",
             ]
         )
@@ -402,36 +474,36 @@ class ReportGenerator:
         """Format a single policy's issues for the comment."""
         lines = []
 
-        lines.append("<details open>")
+        lines.append("<details>")
         lines.append(
-            f"<summary><b>{idx}. <code>{result.policy_file}</code></b> - {len(result.issues)} issue(s) found</summary>"
+            f"<summary>📋 <b>{idx}. <code>{result.policy_file}</code></b> - {len(result.issues)} issue(s) found</summary>"
         )
         lines.append("")
 
         # Group issues by severity - support both IAM validity and security severities
-        errors = [i for i in result.issues if i.severity in ("error", "critical", "high")]
-        warnings = [i for i in result.issues if i.severity in ("warning", "medium")]
-        infos = [i for i in result.issues if i.severity in ("info", "low")]
+        errors = [i for i in result.issues if i.severity in constants.HIGH_SEVERITY_LEVELS]
+        warnings = [i for i in result.issues if i.severity in constants.MEDIUM_SEVERITY_LEVELS]
+        infos = [i for i in result.issues if i.severity in constants.LOW_SEVERITY_LEVELS]
 
         if errors:
             lines.append("### 🔴 Errors")
             lines.append("")
             for issue in errors:
-                lines.append(self._format_issue_markdown(issue))
+                lines.append(self._format_issue_markdown(issue, result.policy_file))
             lines.append("")
 
         if warnings:
             lines.append("### 🟡 Warnings")
             lines.append("")
             for issue in warnings:
-                lines.append(self._format_issue_markdown(issue))
+                lines.append(self._format_issue_markdown(issue, result.policy_file))
             lines.append("")
 
         if infos:
             lines.append("### 🔵 Info")
             lines.append("")
             for issue in infos:
-                lines.append(self._format_issue_markdown(issue))
+                lines.append(self._format_issue_markdown(issue, result.policy_file))
             lines.append("")
 
         lines.append("</details>")
@@ -463,12 +535,18 @@ class ReportGenerator:
 
         return "\n".join(parts)
 
-    def generate_github_comment(self, report: ValidationReport, max_length: int = 65000) -> str:
+    def generate_github_comment(
+        self,
+        report: ValidationReport,
+        max_length: int = constants.GITHUB_MAX_COMMENT_LENGTH,
+        ignored_count: int = 0,
+    ) -> str:
         """Generate a GitHub-flavored markdown comment for PR reviews.
 
         Args:
             report: Validation report
-            max_length: Maximum character length (GitHub limit is 65536, we use 65000 for safety)
+            max_length: Maximum character length (default from GITHUB_MAX_COMMENT_LENGTH constant)
+            ignored_count: Number of findings that were ignored (will be shown in summary)
 
         Returns:
             Markdown formatted string
@@ -476,7 +554,8 @@ class ReportGenerator:
         lines = []
 
         # Header with emoji and status badge
-        if report.invalid_policies == 0:
+        has_parsing_errors = len(report.parsing_errors) > 0
+        if report.invalid_policies == 0 and not has_parsing_errors:
             lines.append("# 🎉 IAM Policy Validation Passed!")
             status_badge = (
                 "![Status](https://img.shields.io/badge/status-passed-success?style=flat-square)"
@@ -502,6 +581,8 @@ class ReportGenerator:
         lines.append(
             f"| **Total Issues Found** | {report.total_issues} | {'⚠️' if report.total_issues > 0 else '✨'} |"
         )
+        if ignored_count > 0:
+            lines.append(f"| **Ignored Findings** | {ignored_count} | 🔕 |")
         lines.append("")
 
         # Issue breakdown
@@ -511,7 +592,7 @@ class ReportGenerator:
                 1
                 for r in report.results
                 for i in r.issues
-                if i.severity in ("error", "critical", "high")
+                if i.severity in constants.HIGH_SEVERITY_LEVELS
             )
             warnings = sum(
                 1 for r in report.results for i in r.issues if i.severity in ("warning", "medium")
@@ -520,8 +601,7 @@ class ReportGenerator:
                 1 for r in report.results for i in r.issues if i.severity in ("info", "low")
             )
 
-            lines.append("<details>")
-            lines.append("<summary><b>🔍 Issue Breakdown</b></summary>")
+            lines.append("### 🔍 Issue Breakdown")
             lines.append("")
             lines.append("| Severity | Count |")
             lines.append("|----------|------:|")
@@ -532,7 +612,28 @@ class ReportGenerator:
             if infos > 0:
                 lines.append(f"| 🔵 **Info** | {infos} |")
             lines.append("")
-            lines.append("</details>")
+
+        # Parsing errors section (if any)
+        if report.parsing_errors:
+            lines.append("### ⚠️ Parsing Errors")
+            lines.append("")
+            lines.append(
+                f"**{len(report.parsing_errors)} file(s) failed to parse** and were excluded from validation:"
+            )
+            lines.append("")
+            for file_path, error_msg in report.parsing_errors:
+                # Extract just the filename for cleaner display
+                from pathlib import Path
+
+                filename = Path(file_path).name
+                lines.append(f"- **`{filename}`**")
+                lines.append("  ```")
+                lines.append(f"  {error_msg}")
+                lines.append("  ```")
+            lines.append("")
+            lines.append(
+                "> **Note:** Fix these parsing errors first before validation can proceed on these files."
+            )
             lines.append("")
 
         # Store header for later (we always include this)
@@ -540,20 +641,17 @@ class ReportGenerator:
 
         # Footer (we always include this)
         footer_lines = [
+            "",
             "---",
             "",
             "<div align='center'>",
-            "",
-            "**🤖 Generated by IAM Policy Validator**",
-            "",
-            "_Powered by AWS IAM Access Analyzer and custom policy checks_",
-            "",
+            "🤖 <em>Generated by <strong>IAM Policy Validator</strong></em><br>",
             "</div>",
         ]
         footer_content = "\n".join(footer_lines)
 
         # Calculate remaining space for details
-        base_length = len(header_content) + len(footer_content) + 100  # 100 for safety
+        base_length = len(header_content) + len(footer_content) + constants.FORMATTING_SAFETY_BUFFER
         available_length = max_length - base_length
 
         # Detailed findings
@@ -570,7 +668,7 @@ class ReportGenerator:
             sorted_results = sorted(
                 [(idx, r) for idx, r in enumerate(report.results, 1) if r.issues],
                 key=lambda x: (
-                    -sum(1 for i in x[1].issues if i.severity in ("error", "critical", "high")),
+                    -sum(1 for i in x[1].issues if i.severity in constants.HIGH_SEVERITY_LEVELS),
                     -len(x[1].issues),
                 ),
             )
@@ -580,23 +678,36 @@ class ReportGenerator:
                     continue
 
                 policy_lines = []
-                policy_lines.append("<details open>")
-                policy_lines.append(
-                    f"<summary><b>{idx}. <code>{result.policy_file}</code></b> - {len(result.issues)} issue(s) found</summary>"
-                )
-                policy_lines.append("")
 
                 # Group issues by severity - support both IAM validity and security severities
-                errors = [i for i in result.issues if i.severity in ("error", "critical", "high")]
+                errors = [i for i in result.issues if i.severity in constants.HIGH_SEVERITY_LEVELS]
                 warnings = [i for i in result.issues if i.severity in ("warning", "medium")]
                 infos = [i for i in result.issues if i.severity in ("info", "low")]
 
+                # Build severity summary for header
+                severity_parts = []
+                if errors:
+                    severity_parts.append(f"🔴 {len(errors)}")
+                if warnings:
+                    severity_parts.append(f"🟡 {len(warnings)}")
+                if infos:
+                    severity_parts.append(f"🔵 {len(infos)}")
+                severity_summary = " · ".join(severity_parts)
+
+                # Only open first 3 policy details by default to avoid wall of text
+                # is_open = " open" if policies_shown < 3 else ""
+                policy_lines.append("<details>")
+                policy_lines.append(
+                    f"<summary><b>{idx}. <code>{result.policy_file}</code></b> - {severity_summary}</summary>"
+                )
+                policy_lines.append("")
+
                 # Add errors (prioritized)
                 if errors:
                     policy_lines.append("### 🔴 Errors")
                     policy_lines.append("")
-                    for issue in errors:
-                        issue_content = self._format_issue_markdown(issue)
+                    for i, issue in enumerate(errors):
+                        issue_content = self._format_issue_markdown(issue, result.policy_file)
                         test_length = len("\n".join(details_lines + policy_lines)) + len(
                             issue_content
                         )
@@ -605,6 +716,10 @@ class ReportGenerator:
                             break
                         policy_lines.append(issue_content)
                         issues_shown += 1
+                        # Add separator between issues within same severity
+                        if i < len(errors) - 1:
+                            policy_lines.append("---")
+                            policy_lines.append("")
                     policy_lines.append("")
 
                 if truncated:
@@ -614,8 +729,8 @@ class ReportGenerator:
                 if warnings:
                     policy_lines.append("### 🟡 Warnings")
                     policy_lines.append("")
-                    for issue in warnings:
-                        issue_content = self._format_issue_markdown(issue)
+                    for i, issue in enumerate(warnings):
+                        issue_content = self._format_issue_markdown(issue, result.policy_file)
                         test_length = len("\n".join(details_lines + policy_lines)) + len(
                             issue_content
                         )
@@ -624,6 +739,10 @@ class ReportGenerator:
                             break
                         policy_lines.append(issue_content)
                         issues_shown += 1
+                        # Add separator between issues within same severity
+                        if i < len(warnings) - 1:
+                            policy_lines.append("---")
+                            policy_lines.append("")
                     policy_lines.append("")
 
                 if truncated:
@@ -633,8 +752,8 @@ class ReportGenerator:
                 if infos:
                     policy_lines.append("### 🔵 Info")
                     policy_lines.append("")
-                    for issue in infos:
-                        issue_content = self._format_issue_markdown(issue)
+                    for i, issue in enumerate(infos):
+                        issue_content = self._format_issue_markdown(issue, result.policy_file)
                         test_length = len("\n".join(details_lines + policy_lines)) + len(
                             issue_content
                         )
@@ -643,6 +762,10 @@ class ReportGenerator:
                             break
                         policy_lines.append(issue_content)
                         issues_shown += 1
+                        # Add separator between issues within same severity
+                        if i < len(infos) - 1:
+                            policy_lines.append("---")
+                            policy_lines.append("")
                     policy_lines.append("")
 
                 if truncated:
@@ -660,6 +783,15 @@ class ReportGenerator:
                 details_lines.extend(policy_lines)
                 policies_shown += 1
 
+                # Add separator between policies (but not after the last one)
+                # The footer will add its own separator
+                if (
+                    policies_shown < len([r for r in sorted_results if r[1].issues])
+                    and not truncated
+                ):
+                    details_lines.append("---")
+                    details_lines.append("")
+
             # Add truncation warning if needed
             if truncated:
                 remaining_policies = len([r for r in report.results if r.issues]) - policies_shown
@@ -696,11 +828,33 @@ class ReportGenerator:
 
         return "\n".join(lines)
 
-    def _format_issue_markdown(self, issue: ValidationIssue) -> str:
-        """Format a single issue as markdown."""
-        location = f"Statement {issue.statement_index}"
-        if issue.statement_sid:
-            location = f"`{issue.statement_sid}` (index {issue.statement_index})"
+    def _format_issue_markdown(self, issue: ValidationIssue, policy_file: str | None = None) -> str:
+        """Format a single issue as markdown.
+
+        Args:
+            issue: The validation issue to format
+            policy_file: Optional policy file path (currently unused, kept for compatibility)
+        """
+        # Handle policy-level issues (statement_index = -1)
+        if issue.statement_index == -1:
+            location = "Policy-level"
+        else:
+            # Use 1-indexed statement numbers for user-facing output
+            statement_num = issue.statement_index + 1
+
+            # Build statement location reference
+            # Note: We show plain text here instead of links because:
+            # 1. GitHub's diff anchor format only works for files in the PR diff
+            # 2. Inline review comments (posted separately) already provide perfect navigation
+            # 3. Summary comment is for overview, not detailed navigation
+            if issue.line_number:
+                location = f"Statement {statement_num} (Line {issue.line_number})"
+                if issue.statement_sid:
+                    location = f"`{issue.statement_sid}` (statement {statement_num}, line {issue.line_number})"
+            else:
+                location = f"Statement {statement_num}"
+                if issue.statement_sid:
+                    location = f"`{issue.statement_sid}` (statement {statement_num})"
 
         parts = []
 
@@ -712,7 +866,7 @@ class ReportGenerator:
         parts.append(f"> {issue.message}")
         parts.append("")
 
-        # Details section
+        # Details section - inline format
         details = []
         if issue.action:
             details.append(f"**Action:** `{issue.action}`")
@@ -722,18 +876,37 @@ class ReportGenerator:
             details.append(f"**Condition Key:** `{issue.condition_key}`")
 
         if details:
-            parts.append("<table>")
-            parts.append("<tr><td>")
-            parts.append("")
-            parts.extend(details)
-            parts.append("")
-            parts.append("</td></tr>")
-            parts.append("</table>")
+            parts.append(" · ".join(details))
             parts.append("")
 
-        # Suggestion in highlighted box
+        # Suggestion in highlighted box with code examples
         if issue.suggestion:
-            parts.append(f"> 💡 **Suggestion:** {issue.suggestion}")
+            # Check if suggestion contains "Example:" section
+            if "\nExample:\n" in issue.suggestion:
+                text_part, code_part = issue.suggestion.split("\nExample:\n", 1)
+                parts.append(f"> 💡 **Suggestion:** {text_part}")
+                parts.append("")
+                parts.append("<details>")
+                parts.append("<summary>📖 View Example</summary>")
+                parts.append("")
+                parts.append("```json")
+                parts.append(code_part)
+                parts.append("```")
+                parts.append("</details>")
+                parts.append("")
+            else:
+                parts.append(f"> 💡 **Suggestion:** {issue.suggestion}")
+                parts.append("")
+
+        # Handle separate example field (if not already in suggestion)
+        if issue.example and "\nExample:\n" not in (issue.suggestion or ""):
+            parts.append("<details>")
+            parts.append("<summary>📖 View Example</summary>")
+            parts.append("")
+            parts.append("```json")
+            parts.append(issue.example)
+            parts.append("```")
+            parts.append("</details>")
             parts.append("")
 
         return "\n".join(parts)
